On 3/12/2014 1:34 PM, Ben Hutchings wrote:
On Tue, 2014-03-11 at 22:42 -0500, cls...@linux.vnet.ibm.com wrote:
[...]
Index: b/include/linux/mlx5/driver.h
===================================================================
--- a/include/linux/mlx5/driver.h
+++ b/include/linux/mlx5/driver.h
@@ -51,10 +51,10 @@ enum {
  };
enum {
        /* one minute for the sake of bringup. Generally, commands must always
          * complete and we may need to increase this timeout value
          */
-       MLX5_CMD_TIMEOUT_MSEC   = 7200 * 1000,
+       MLX5_CMD_TIMEOUT_MSEC   = 10 * 1000,
@@ -51,10 +51,10 @@ enum {
  };
enum {
-       /* one minute for the sake of bringup. Generally, commands must always
+       /* 10 msecs for the sake of bringup. Generally, commands must always
          * complete and we may need to increase this timeout value
          */
You seem to be changing the timeout from 2 hours (not one minute) to 10
seconds (not milliseconds).

Ben.
Yes you are right the comment should say 10 seconds instead of 10 msecs.

Carol

         MLX5_CMD_WQ_MAX_NAME    = 32,
  };


--
To unsubscribe from this list: send the line "unsubscribe linux-rdma" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to